@@ -1,5 +1,5 @@
 # sqlalchemy/__init__.py
-# Copyright (C) 2005-2021 the SQLAlchemy authors and contributors
+# Copyright (C) 2005-2019 the SQLAlchemy authors and contributors
 # <see AUTHORS file>
 #
 # This module is part of SQLAlchemy and is released under
@@ -11,14 +11,12 @@ from .schema import BLANK_SCHEMA  # noqa
 from .schema import CheckConstraint  # noqa
 from .schema import Column  # noqa
 from .schema import ColumnDefault  # noqa
-from .schema import Computed  # noqa
 from .schema import Constraint  # noqa
 from .schema import DDL  # noqa
 from .schema import DefaultClause  # noqa
 from .schema import FetchedValue  # noqa
 from .schema import ForeignKey  # noqa
 from .schema import ForeignKeyConstraint  # noqa
-from .schema import IdentityOptions  # noqa
 from .schema import Index  # noqa
 from .schema import MetaData  # noqa
 from .schema import PassiveDefault  # noqa
@@ -124,7 +122,7 @@ from .engine import create_engine  # noqa nosort
 from .engine import engine_from_config  # noqa nosort
 
 
-__version__ = "1.3.24"
+__version__ = "1.3.3"
 
 
 def __go(lcls):
@@ -143,9 +141,5 @@ def __go(lcls):
 
     _sa_util.dependencies.resolve_all("sqlalchemy")
 
-    from . import exc
-
-    exc._version_token = "".join(__version__.split(".")[0:2])
-
 
 __go(locals())
